from distutils.core import setup

setup(
  name = 'person-extractor',
  packages = ['person_extractor'],
  version = '2.4',
  description = 'Extracts people from text',
  author = 'Daniel J. Dufour',
  author_email = 'daniel.j.dufour@gmail.com',
  url = 'https://github.com/DanielJDufour/person-extractor',
  download_url = 'https://github.com/DanielJDufour/person-extractor/tarball/download',
  keywords = ['language','persons','people','parsing','python'],
  classifiers = [],
)
